import aiohttp
import asyncio
import json
from bs4 import BeautifulSoup

url = "https://www.tiktok.com/@"

suffix = "/video/"

async def latest_links(username, count):
    async with aiohttp.ClientSession() as session:
        async with session.get(url + username) as response:
            html = await response.text()

            soup = BeautifulSoup(html, "html.parser")

            scripts = soup.find_all("script", attrs={"type": "application/json"})

            for script in scripts:
                if "user-post" not in str(script):
                    continue

                profile_data = json.loads(script.string)
                item_list = profile_data.get("ItemList")

                user_post = item_list.get("user-post")
                post_urls = user_post.get("list")

                for id in post_urls[:count]:
                    complete_url = url + username + suffix + id  # 10 latest videos
                    print(complete_url)


def followers(username):
    pass

def likes(username):
    pass

def following(username):
    pass

def profileUrl(username):
    pass


async def get_latest_vid_links(username, count):
    await latest_links(username, count)


import requests
from bs4 import BeautifulSoup

def get_insta_followers(username):
    # Send a GET request to fetch the profile page
    response = requests.get(f"https://www.instagram.com/{username}/")

    if response.status_code == 200:
        try:
            soup = BeautifulSoup(response.content, "html.parser")
            # Extract the meta description from the HTML
            meta_description = soup.find("meta", property="og:description")["content"]

            # Extract the followers count from the meta description
            followers_count = meta_description.split("-")[0].strip().split(" ")[0]
            return followers_count
        except (KeyError, ValueError):
            return "Unable to fetch followers count."
    else:
        return "Unable to fetch profile page. Please check the profile name."


def get_insta_following(username):
    # Send a GET request to fetch the profile page
    response = requests.get(f"https://www.instagram.com/{username}/")

    if response.status_code == 200:
        try:
            soup = BeautifulSoup(response.content, "html.parser")
            # Extract the meta description from the HTML
            meta_description = soup.find("meta", property="og:description")["content"]

            # Extract the following count from the meta description
            following_count = meta_description.split("-")[0].strip().split(" ")[2]
            return following_count
        except (KeyError, ValueError):
            return "Unable to fetch following count."
    else:
        return "Unable to fetch profile page. Please check the profile name."


def get_insta_posts(username):
    # Send a GET request to fetch the profile page
    response = requests.get(f"https://www.instagram.com/{username}/")

    if response.status_code == 200:
        try:
            soup = BeautifulSoup(response.content, "html.parser")
            # Extract the meta description from the HTML
            meta_description = soup.find("meta", property="og:description")["content"]

            # Extract the posts count from the meta description
            posts_count = meta_description.split("-")[0].strip().split(" ")[4]
            return posts_count
        except (KeyError, ValueError):
            return "Unable to fetch posts count."
    else:
        return "Unable to fetch profile page. Please check the profile name."